summaryrefslogtreecommitdiffstats
path: root/kexi/3rdparty/kexisql3/src/pragma.c
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-09 02:23:29 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-09 02:23:29 +0000
commit7c71ab86d1f7e387fc3df63b48df07231f111862 (patch)
tree30ba2d2f840ff5fd458b6113e9c3f2e8a71d510d /kexi/3rdparty/kexisql3/src/pragma.c
parentafbfdc507bfaafc8824a9808311d57a9ece87510 (diff)
downloadkoffice-7c71ab86d1f7e387fc3df63b48df07231f111862.tar.gz
koffice-7c71ab86d1f7e387fc3df63b48df07231f111862.zip
Remove the tq in front of these incorrectly TQt4-converted methods/data members:
tqrepaint[...] tqinvalidate[...] tqparent[...] tqmask[...] tqlayout[...] tqalignment[...] git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1240522 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kexi/3rdparty/kexisql3/src/pragma.c')
-rw-r--r--kexi/3rdparty/kexisql3/src/pragma.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/kexi/3rdparty/kexisql3/src/pragma.c b/kexi/3rdparty/kexisql3/src/pragma.c
index 618ce9e1..181d9a94 100644
--- a/kexi/3rdparty/kexisql3/src/pragma.c
+++ b/kexi/3rdparty/kexisql3/src/pragma.c
@@ -86,7 +86,7 @@ static int getTempStore(const char *z){
** Invalidate temp storage, either when the temp storage is changed
** from default, or when 'file' and the temp_store_directory has changed
*/
-static int tqinvalidateTempStorage(Parse *pParse){
+static int invalidateTempStorage(Parse *pParse){
sqlite3 *db = pParse->db;
if( db->aDb[1].pBt!=0 ){
if( db->flags & SQLITE_InTrans ){
@@ -112,7 +112,7 @@ static int changeTempStorage(Parse *pParse, const char *zStorageType){
int ts = getTempStore(zStorageType);
sqlite3 *db = pParse->db;
if( db->temp_store==ts ) return SQLITE_OK;
- if( tqinvalidateTempStorage( pParse ) != SQLITE_OK ){
+ if( invalidateTempStorage( pParse ) != SQLITE_OK ){
return SQLITE_ERROR;
}
db->temp_store = ts;
@@ -377,7 +377,7 @@ void sqlite3Pragma(
** Return or set the local value of the temp_store_directory flag. Changing
** the value sets a specific directory to be used for temporary files.
** Setting to a null string reverts to the default temporary directory search.
** If temporary directory is changed, then tqinvalidateTempStorage.
**
*/
if( sqlite3StrICmp(zLeft, "temp_store_directory")==0 ){
@@ -397,7 +397,7 @@ void sqlite3Pragma(
|| (TEMP_STORE==1 && db->temp_store<=1)
|| (TEMP_STORE==2 && db->temp_store==1)
){
- tqinvalidateTempStorage(pParse);
+ invalidateTempStorage(pParse);
}
sqliteFree(sqlite3_temp_directory);
if( zRight[0] ){
@@ -377,7 +377,7 @@ void sqlite3Pragma(
** the value sets a specific directory to be used for temporary files.
** Setting to a null string reverts to the default temporary directory search.
- ** If temporary directory is changed, then tqinvalidateTempStorage.
+ ** If temporary directory is changed, then invalidateTempStorage.
**
*/